pub struct ModuleConfig {
pub homeservers: Vec<String>,
pub keywords_join: Vec<String>,
pub keywords_leave: Vec<String>,
pub leave_message: String,
}Expand description
Module configuration
Fields
homeservers: Vec<String>List of homeservers to which room ids belong to that the bot will be allowed to join
keywords_join: Vec<String>Keywords for join requests.
keywords_leave: Vec<String>Keywords for leave requests.
leave_message: StringMessage the bot will send to the channel when instructed to leave