pub struct ForgejoConfig {
pub rooms: HashMap<String, String>,
pub feed_interval: u64,
pub objects_count: u16,
pub instances: HashMap<String, ForgejoInstance>,
pub keywords_pr_new: Vec<String>,
pub keywords_pr_old: Vec<String>,
pub keywords_issue_new: Vec<String>,
pub keywords_issue_old: Vec<String>,
}Expand description
General module configuration
Fields
rooms: HashMap<String, String>Instance to act upon in a given room. Special key “default” signifies the default instance if none is configured for a given room.
feed_interval: u64How often the feeds should be checked, in minutes.
objects_count: u16How many issues/PRs should be returned on active queries
instances: HashMap<String, ForgejoInstance>Map of Forgejo instances to query and observe
keywords_pr_new: Vec<String>Keywords for displaying list of latest open pull requests.
keywords_pr_old: Vec<String>Keywords for displaying list of oldest open pull requests.
keywords_issue_new: Vec<String>Keywords for displaying list of latest open issues.
keywords_issue_old: Vec<String>Keywords for displaying list of oldest open issues.