pub type CatchallDecider = fn(klaczlevel: i64, sender: OwnedUserId, room: &Room, content: &RoomMessageEventContent, config: &Config) -> Result<Consumption>;Expand description
Function signature for Decider function for non-keyword modules.
Returns Consumption to indicate whether or not the module will want to consume the event, and in what exclusivity manner.